@@ -1,15 +1,17 @@
 from __future__ import annotations
-from typing import Any, Dict, List, Optional, Set, Tuple, Union, TYPE_CHECKING
-from itertools import groupby
 
+from itertools import groupby
+from typing import TYPE_CHECKING
+
+# pyre-ignore[21]
 from s2clientprotocol import raw_pb2 as raw_pb
 
-from .position import Point2
-from .unit import Unit
+from sc2.position import Point2
+from sc2.unit import Unit
 
 if TYPE_CHECKING:
-    from .unit_command import UnitCommand
-    from .ids.ability_id import AbilityId
+    from sc2.ids.ability_id import AbilityId
+    from sc2.unit_command import UnitCommand
 
 
 def combine_actions(action_iter):
@@ -24,7 +26,7 @@ def combine_actions(action_iter):
     """
     for key, items in groupby(action_iter, key=lambda a: a.combining_tuple):
         ability: AbilityId
-        target: Union[None, Point2, Unit]
+        target: None | Point2 | Unit
         queue: bool
         # See constants.py for combineable abilities
         combineable: bool
