@@ -1,11 +1,10 @@
-# pylint: disable=W0212
+# pyre-ignore-all-errors[29]
 from __future__ import annotations
 
 from bisect import bisect_left
 from contextlib import suppress
 from dataclasses import dataclass
 from functools import lru_cache
-from typing import Dict, List, Optional, Union
 
 from sc2.data import Attribute, Race
 from sc2.ids.ability_id import AbilityId
@@ -21,22 +20,20 @@ FREE_ABILITIES = {"Lower", "Raise", "Land", "Lift", "Hold", "Harvest"}
 
 
 class GameData:
-
-    def __init__(self, data):
+    def __init__(self, data) -> None:
         """
         :param data:
         """
-        ids = set(a.value for a in AbilityId if a.value != 0)
-        self.abilities: Dict[int, AbilityData] = {
-            a.ability_id: AbilityData(self, a)
-            for a in data.abilities if a.ability_id in ids
+        ids = {a.value for a in AbilityId if a.value != 0}
+        self.abilities: dict[int, AbilityData] = {
+            a.ability_id: AbilityData(self, a) for a in data.abilities if a.ability_id in ids
         }
-        self.units: Dict[int, UnitTypeData] = {u.unit_id: UnitTypeData(self, u) for u in data.units if u.available}
-        self.upgrades: Dict[int, UpgradeData] = {u.upgrade_id: UpgradeData(self, u) for u in data.upgrades}
+        self.units: dict[int, UnitTypeData] = {u.unit_id: UnitTypeData(self, u) for u in data.units if u.available}
+        self.upgrades: dict[int, UpgradeData] = {u.upgrade_id: UpgradeData(self, u) for u in data.upgrades}
         # Cached UnitTypeIds so that conversion does not take long. This needs to be moved elsewhere if a new GameData object is created multiple times per game
 
     @lru_cache(maxsize=256)
-    def calculate_ability_cost(self, ability: Union[AbilityData, AbilityId, UnitCommand]) -> Cost:
+    def calculate_ability_cost(self, ability: AbilityData | AbilityId | UnitCommand) -> Cost:
         if isinstance(ability, AbilityId):
             ability = self.abilities[ability.value]
         elif isinstance(ability, UnitCommand):
@@ -51,6 +48,7 @@ class GameData:
             if not AbilityData.id_exists(unit.creation_ability.id.value):
                 continue
 
+            # pyre-ignore[16]
             if unit.creation_ability.is_free_morph:
                 continue
 
@@ -58,6 +56,9 @@ class GameData:
                 if unit.id == UnitTypeId.ZERGLING:
                     # HARD CODED: zerglings are generated in pairs
                     return Cost(unit.cost.minerals * 2, unit.cost.vespene * 2, unit.cost.time)
+                if unit.id == UnitTypeId.BANELING:
+                    # HARD CODED: banelings don't cost 50/25 as described in the API, but 25/25
+                    return Cost(25, 25, unit.cost.time)
                 # Correction for morphing units, e.g. orbital would return 550/0 instead of actual 150/0
                 morph_cost = unit.morph_cost
                 if morph_cost:  # can be None
@@ -73,8 +74,7 @@ class GameData:
 
 
 class AbilityData:
-
-    ability_ids: List[int] = [ability_id.value for ability_id in AbilityId][1:]  # sorted list
+    ability_ids: list[int] = [ability_id.value for ability_id in AbilityId][1:]  # sorted list
 
     @classmethod
     def id_exists(cls, ability_id):
@@ -84,7 +84,7 @@ class AbilityData:
         i = bisect_left(cls.ability_ids, ability_id)  # quick binary search
         return i != len(cls.ability_ids) and cls.ability_ids[i] == ability_id
 
-    def __init__(self, game_data, proto):
+    def __init__(self, game_data, proto) -> None:
         self._game_data = game_data
         self._proto = proto
 
@@ -96,29 +96,29 @@ class AbilityData:
 
     @property
     def id(self) -> AbilityId:
-        """ Returns the generic remap ID. See sc2/dicts/generic_redirect_abilities.py """
+        """Returns the generic remap ID. See sc2/dicts/generic_redirect_abilities.py"""
         if self._proto.remaps_to_ability_id:
             return AbilityId(self._proto.remaps_to_ability_id)
         return AbilityId(self._proto.ability_id)
 
     @property
     def exact_id(self) -> AbilityId:
-        """ Returns the exact ID of the ability """
+        """Returns the exact ID of the ability"""
         return AbilityId(self._proto.ability_id)
 
     @property
     def link_name(self) -> str:
-        """ For Stimpack this returns 'BarracksTechLabResearch' """
+        """For Stimpack this returns 'BarracksTechLabResearch'"""
         return self._proto.link_name
 
     @property
     def button_name(self) -> str:
-        """ For Stimpack this returns 'Stimpack' """
+        """For Stimpack this returns 'Stimpack'"""
         return self._proto.button_name
 
     @property
     def friendly_name(self) -> str:
-        """ For Stimpack this returns 'Research Stimpack' """
+        """For Stimpack this returns 'Research Stimpack'"""
         return self._proto.friendly_name
 
     @property
@@ -131,8 +131,7 @@ class AbilityData:
 
 
 class UnitTypeData:
-
-    def __init__(self, game_data: GameData, proto):
+    def __init__(self, game_data: GameData, proto) -> None:
         """
         :param game_data:
         :param proto:
@@ -158,7 +157,7 @@ class UnitTypeData:
         return self._proto.name
 
     @property
-    def creation_ability(self) -> Optional[AbilityData]:
+    def creation_ability(self) -> AbilityData | None:
         if self._proto.ability_id == 0:
             return None
         if self._proto.ability_id not in self._game_data.abilities:
@@ -166,17 +165,19 @@ class UnitTypeData:
         return self._game_data.abilities[self._proto.ability_id]
 
     @property
-    def footprint_radius(self) -> Optional[float]:
-        """ See unit.py footprint_radius """
+    def footprint_radius(self) -> float | None:
+        """See unit.py footprint_radius"""
         if self.creation_ability is None:
             return None
         return self.creation_ability._proto.footprint_radius
 
     @property
-    def attributes(self) -> List[Attribute]:
+    # pyre-ignore[11]
+    def attributes(self) -> list[Attribute]:
         return self._proto.attributes
 
     def has_attribute(self, attr) -> bool:
+        # pyre-ignore[6]
         assert isinstance(attr, Attribute)
         return attr in self.attributes
 
@@ -190,12 +191,12 @@ class UnitTypeData:
 
     @property
     def cargo_size(self) -> int:
-        """ How much cargo this unit uses up in cargo_space """
+        """How much cargo this unit uses up in cargo_space"""
         return self._proto.cargo_size
 
     @property
-    def tech_requirement(self) -> Optional[UnitTypeId]:
-        """ Tech-building requirement of buildings - may work for units but unreliably """
+    def tech_requirement(self) -> UnitTypeId | None:
+        """Tech-building requirement of buildings - may work for units but unreliably"""
         if self._proto.tech_requirement == 0:
             return None
         if self._proto.tech_requirement not in self._game_data.units:
@@ -203,7 +204,7 @@ class UnitTypeData:
         return UnitTypeId(self._proto.tech_requirement)
 
     @property
-    def tech_alias(self) -> Optional[List[UnitTypeId]]:
+    def tech_alias(self) -> list[UnitTypeId] | None:
         """Building tech equality, e.g. OrbitalCommand is the same as CommandCenter
         Building tech equality, e.g. Hive is the same as Lair and Hatchery
         For Hive, this returns [UnitTypeId.Hatchery, UnitTypeId.Lair]
@@ -214,8 +215,8 @@ class UnitTypeData:
         return return_list if return_list else None
 
     @property
-    def unit_alias(self) -> Optional[UnitTypeId]:
-        """ Building type equality, e.g. FlyingOrbitalCommand is the same as OrbitalCommand """
+    def unit_alias(self) -> UnitTypeId | None:
+        """Building type equality, e.g. FlyingOrbitalCommand is the same as OrbitalCommand"""
         if self._proto.unit_alias == 0:
             return None
         if self._proto.unit_alias not in self._game_data.units:
@@ -224,6 +225,7 @@ class UnitTypeData:
         return UnitTypeId(self._proto.unit_alias)
 
     @property
+    # pyre-ignore[11]
     def race(self) -> Race:
         return Race(self._proto.race)
 
@@ -233,14 +235,15 @@ class UnitTypeData:
 
     @property
     def cost_zerg_corrected(self) -> Cost:
-        """ This returns 25 for extractor and 200 for spawning pool instead of 75 and 250 respectively """
+        """This returns 25 for extractor and 200 for spawning pool instead of 75 and 250 respectively"""
+        # pyre-ignore[16]
         if self.race == Race.Zerg and Attribute.Structure.value in self.attributes:
             return Cost(self._proto.mineral_cost - 50, self._proto.vespene_cost, self._proto.build_time)
         return self.cost
 
     @property
-    def morph_cost(self) -> Optional[Cost]:
-        """ This returns 150 minerals for OrbitalCommand instead of 550 """
+    def morph_cost(self) -> Cost | None:
+        """This returns 150 minerals for OrbitalCommand instead of 550"""
         # Morphing units
         supply_cost = self._proto.food_required
         if supply_cost > 0 and self.id in UNIT_TRAINED_FROM and len(UNIT_TRAINED_FROM[self.id]) == 1:
@@ -265,7 +268,9 @@ class UnitTypeData:
             self._game_data.units[tech_alias.value].cost.minerals for tech_alias in self.tech_alias
         )
         tech_alias_cost_vespene = max(
-            self._game_data.units[tech_alias.value].cost.vespene for tech_alias in self.tech_alias
+            self._game_data.units[tech_alias.value].cost.vespene
+            # pyre-ignore[16]
+            for tech_alias in self.tech_alias
         )
         return Cost(
             self._proto.mineral_cost - tech_alias_cost_minerals,
@@ -275,8 +280,7 @@ class UnitTypeData:
 
 
 class UpgradeData:
-
-    def __init__(self, game_data: GameData, proto):
+    def __init__(self, game_data: GameData, proto) -> None:
         """
         :param game_data:
         :param proto:
@@ -284,7 +288,7 @@ class UpgradeData:
         self._game_data = game_data
         self._proto = proto
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f"UpgradeData({self.name} - research ability: {self.research_ability}, {self.cost})"
 
     @property
@@ -292,7 +296,7 @@ class UpgradeData:
         return self._proto.name
 
     @property
-    def research_ability(self) -> Optional[AbilityData]:
+    def research_ability(self) -> AbilityData | None:
         if self._proto.ability_id == 0:
             return None
         if self._proto.ability_id not in self._game_data.abilities:
@@ -310,9 +314,10 @@ class Cost:
     The cost of an action, a structure, a unit or a research upgrade.
     The time is given in frames (22.4 frames per game second).
     """
+
     minerals: int
     vespene: int
-    time: Optional[float] = None
+    time: float | None = None
 
     def __repr__(self) -> str:
         return f"Cost({self.minerals}, {self.vespene})"
@@ -326,7 +331,7 @@ class Cost:
     def __bool__(self) -> bool:
         return self.minerals != 0 or self.vespene != 0
 
-    def __add__(self, other) -> Cost:
+    def __add__(self, other: Cost) -> Cost:
         if not other:
             return self
         if not self:
