@@ -1,37 +1,39 @@
+# pyre-ignore-all-errors[6, 14, 15, 58]
 from __future__ import annotations
 
 import itertools
 import math
 import random
-from typing import TYPE_CHECKING, Iterable, List, Set, Tuple, Union
+from collections.abc import Iterable
+from typing import TYPE_CHECKING, SupportsFloat, SupportsIndex
 
+# pyre-fixme[21]
 from s2clientprotocol import common_pb2 as common_pb
 
 if TYPE_CHECKING:
     from sc2.unit import Unit
     from sc2.units import Units
 
-EPSILON = 10**-8
+EPSILON: float = 10**-8
 
 
-def _sign(num):
+def _sign(num: SupportsFloat | SupportsIndex) -> float:
     return math.copysign(1, num)
 
 
 class Pointlike(tuple):
-
     @property
     def position(self) -> Pointlike:
         return self
 
-    def distance_to(self, target: Union[Unit, Point2]) -> float:
+    def distance_to(self, target: Unit | Point2) -> float:
         """Calculate a single distance from a point or unit to another point or unit
 
         :param target:"""
         p = target.position
         return math.hypot(self[0] - p[0], self[1] - p[1])
 
-    def distance_to_point2(self, p: Union[Point2, Tuple[float, float]]) -> float:
+    def distance_to_point2(self, p: Point2 | tuple[float, float]) -> float:
         """Same as the function above, but should be a bit faster because of the dropped asserts
         and conversion.
 
@@ -43,9 +45,9 @@ class Pointlike(tuple):
         This is to speed up the sorting process.
 
         :param p2:"""
-        return (self[0] - p2[0])**2 + (self[1] - p2[1])**2
+        return (self[0] - p2[0]) ** 2 + (self[1] - p2[1]) ** 2
 
-    def sort_by_distance(self, ps: Union[Units, Iterable[Point2]]) -> List[Point2]:
+    def sort_by_distance(self, ps: Units | Iterable[Point2]) -> list[Point2]:
         """This returns the target points sorted as list.
         You should not pass a set or dict since those are not sortable.
         If you want to sort your units towards a point, use 'units.sorted_by_distance_to(point)' instead.
@@ -53,15 +55,15 @@ class Pointlike(tuple):
         :param ps:"""
         return sorted(ps, key=lambda p: self.distance_to_point2(p.position))
 
-    def closest(self, ps: Union[Units, Iterable[Point2]]) -> Union[Unit, Point2]:
+    def closest(self, ps: Units | Iterable[Point2]) -> Unit | Point2:
         """This function assumes the 2d distance is meant
 
         :param ps:"""
         assert ps, "ps is empty"
-        # pylint: disable=W0108
+
         return min(ps, key=lambda p: self.distance_to(p))
 
-    def distance_to_closest(self, ps: Union[Units, Iterable[Point2]]) -> float:
+    def distance_to_closest(self, ps: Units | Iterable[Point2]) -> float:
         """This function assumes the 2d distance is meant
         :param ps:"""
         assert ps, "ps is empty"
@@ -73,15 +75,15 @@ class Pointlike(tuple):
                 closest_distance = distance
         return closest_distance
 
-    def furthest(self, ps: Union[Units, Iterable[Point2]]) -> Union[Unit, Pointlike]:
+    def furthest(self, ps: Units | Iterable[Point2]) -> Unit | Pointlike:
         """This function assumes the 2d distance is meant
 
         :param ps: Units object, or iterable of Unit or Point2"""
         assert ps, "ps is empty"
-        # pylint: disable=W0108
+
         return max(ps, key=lambda p: self.distance_to(p))
 
-    def distance_to_furthest(self, ps: Union[Units, Iterable[Point2]]) -> float:
+    def distance_to_furthest(self, ps: Units | Iterable[Point2]) -> float:
         """This function assumes the 2d distance is meant
 
         :param ps:"""
@@ -99,16 +101,16 @@ class Pointlike(tuple):
 
         :param p:
         """
-        return self.__class__(a + b for a, b in itertools.zip_longest(self, p[:len(self)], fillvalue=0))
+        return self.__class__(a + b for a, b in itertools.zip_longest(self, p[: len(self)], fillvalue=0))
 
-    def unit_axes_towards(self, p):
+    def unit_axes_towards(self, p) -> Pointlike:
         """
 
         :param p:
         """
-        return self.__class__(_sign(b - a) for a, b in itertools.zip_longest(self, p[:len(self)], fillvalue=0))
+        return self.__class__(_sign(b - a) for a, b in itertools.zip_longest(self, p[: len(self)], fillvalue=0))
 
-    def towards(self, p: Union[Unit, Pointlike], distance: Union[int, float] = 1, limit: bool = False) -> Pointlike:
+    def towards(self, p: Unit | Pointlike, distance: int | float = 1, limit: bool = False) -> Pointlike:
         """
 
         :param p:
@@ -125,22 +127,20 @@ class Pointlike(tuple):
         if limit:
             distance = min(d, distance)
         return self.__class__(
-            a + (b - a) / d * distance for a, b in itertools.zip_longest(self, p[:len(self)], fillvalue=0)
+            a + (b - a) / d * distance for a, b in itertools.zip_longest(self, p[: len(self)], fillvalue=0)
         )
 
-    def __eq__(self, other):
+    def __eq__(self, other: object) -> bool:
         try:
             return all(abs(a - b) <= EPSILON for a, b in itertools.zip_longest(self, other, fillvalue=0))
         except TypeError:
             return False
 
-    def __hash__(self):
+    def __hash__(self) -> int:
         return hash(tuple(self))
 
 
-# pylint: disable=R0904
 class Point2(Pointlike):
-
     @classmethod
     def from_proto(cls, data) -> Point2:
         """
@@ -149,10 +149,12 @@ class Point2(Pointlike):
         return cls((data.x, data.y))
 
     @property
+    # pyre-fixme[11]
     def as_Point2D(self) -> common_pb.Point2D:
         return common_pb.Point2D(x=self.x, y=self.y)
 
     @property
+    # pyre-fixme[11]
     def as_PointI(self) -> common_pb.PointI:
         """Represents points on the minimap. Values must be between 0 and 64."""
         return common_pb.PointI(x=self.x, y=self.y)
@@ -163,12 +165,12 @@ class Point2(Pointlike):
 
     @property
     def length(self) -> float:
-        """ This property exists in case Point2 is used as a vector. """
+        """This property exists in case Point2 is used as a vector."""
         return math.hypot(self[0], self[1])
 
     @property
     def normalized(self) -> Point2:
-        """ This property exists in case Point2 is used as a vector. """
+        """This property exists in case Point2 is used as a vector."""
         length = self.length
         # Cannot normalize if length is zero
         assert length
@@ -190,10 +192,14 @@ class Point2(Pointlike):
     def to3(self) -> Point3:
         return Point3((*self, 0))
 
-    def offset(self, p: Point2):
+    def round(self, decimals: int) -> Point2:
+        """Rounds each number in the tuple to the amount of given decimals."""
+        return Point2((round(self[0], decimals), round(self[1], decimals)))
+
+    def offset(self, p: Point2) -> Point2:
         return Point2((self[0] + p[0], self[1] + p[1]))
 
-    def random_on_distance(self, distance):
+    def random_on_distance(self, distance) -> Point2:
         if isinstance(distance, (tuple, list)):  # interval
             distance = distance[0] + random.random() * (distance[1] - distance[0])
 
@@ -205,40 +211,40 @@ class Point2(Pointlike):
 
     def towards_with_random_angle(
         self,
-        p: Union[Point2, Point3],
-        distance: Union[int, float] = 1,
-        max_difference: Union[int, float] = (math.pi / 4),
+        p: Point2 | Point3,
+        distance: int | float = 1,
+        max_difference: int | float = (math.pi / 4),
     ) -> Point2:
         tx, ty = self.to2.towards(p.to2, 1)
         angle = math.atan2(ty - self.y, tx - self.x)
         angle = (angle - max_difference) + max_difference * 2 * random.random()
         return Point2((self.x + math.cos(angle) * distance, self.y + math.sin(angle) * distance))
 
-    def circle_intersection(self, p: Point2, r: Union[int, float]) -> Set[Point2]:
+    def circle_intersection(self, p: Point2, r: int | float) -> set[Point2]:
         """self is point1, p is point2, r is the radius for circles originating in both points
         Used in ramp finding
 
         :param p:
         :param r:"""
         assert self != p, "self is equal to p"
-        distanceBetweenPoints = self.distance_to(p)
-        assert r >= distanceBetweenPoints / 2
+        distance_between_points = self.distance_to(p)
+        assert r >= distance_between_points / 2
         # remaining distance from center towards the intersection, using pythagoras
-        remainingDistanceFromCenter = (r**2 - (distanceBetweenPoints / 2)**2)**0.5
+        remaining_distance_from_center = (r**2 - (distance_between_points / 2) ** 2) ** 0.5
         # center of both points
-        offsetToCenter = Point2(((p.x - self.x) / 2, (p.y - self.y) / 2))
-        center = self.offset(offsetToCenter)
+        offset_to_center = Point2(((p.x - self.x) / 2, (p.y - self.y) / 2))
+        center = self.offset(offset_to_center)
 
         # stretch offset vector in the ratio of remaining distance from center to intersection
-        vectorStretchFactor = remainingDistanceFromCenter / (distanceBetweenPoints / 2)
-        v = offsetToCenter
-        offsetToCenterStretched = Point2((v.x * vectorStretchFactor, v.y * vectorStretchFactor))
+        vector_stretch_factor = remaining_distance_from_center / (distance_between_points / 2)
+        v = offset_to_center
+        offset_to_center_stretched = Point2((v.x * vector_stretch_factor, v.y * vector_stretch_factor))
 
         # rotate vector by 90° and -90°
-        vectorRotated1 = Point2((offsetToCenterStretched.y, -offsetToCenterStretched.x))
-        vectorRotated2 = Point2((-offsetToCenterStretched.y, offsetToCenterStretched.x))
-        intersect1 = center.offset(vectorRotated1)
-        intersect2 = center.offset(vectorRotated2)
+        vector_rotated_1 = Point2((offset_to_center_stretched.y, -offset_to_center_stretched.x))
+        vector_rotated_2 = Point2((-offset_to_center_stretched.y, offset_to_center_stretched.x))
+        intersect1 = center.offset(vector_rotated_1)
+        intersect2 = center.offset(vector_rotated_2)
         return {intersect1, intersect2}
 
     @property
@@ -275,29 +281,28 @@ class Point2(Pointlike):
         return math.hypot(self.x, self.y)
 
     def __bool__(self) -> bool:
-        if self.x != 0 or self.y != 0:
-            return True
-        return False
+        return self.x != 0 or self.y != 0
 
-    def __mul__(self, other: Union[int, float, Point2]) -> Point2:
+    def __mul__(self, other: int | float | Point2) -> Point2:
         try:
+            # pyre-ignore[16]
             return self.__class__((self.x * other.x, self.y * other.y))
         except AttributeError:
             return self.__class__((self.x * other, self.y * other))
 
-    def __rmul__(self, other: Union[int, float, Point2]) -> Point2:
+    def __rmul__(self, other: int | float | Point2) -> Point2:
         return self.__mul__(other)
 
-    def __truediv__(self, other: Union[int, float, Point2]) -> Point2:
+    def __truediv__(self, other: int | float | Point2) -> Point2:
         if isinstance(other, self.__class__):
             return self.__class__((self.x / other.x, self.y / other.y))
         return self.__class__((self.x / other, self.y / other))
 
-    def is_same_as(self, other: Point2, dist=0.001) -> bool:
+    def is_same_as(self, other: Point2, dist: float = 0.001) -> bool:
         return self.distance_to_point2(other) <= dist
 
     def direction_vector(self, other: Point2) -> Point2:
-        """ Converts a vector to a direction that can face vertically, horizontally or diagonal or be zero, e.g. (0, 0), (1, -1), (1, 0) """
+        """Converts a vector to a direction that can face vertically, horizontally or diagonal or be zero, e.g. (0, 0), (1, -1), (1, 0)"""
         return self.__class__((_sign(other.x - self.x), _sign(other.y - self.y)))
 
     def manhattan_distance(self, other: Point2) -> float:
@@ -307,7 +312,7 @@ class Point2(Pointlike):
         return abs(other.x - self.x) + abs(other.y - self.y)
 
     @staticmethod
-    def center(points: List[Point2]) -> Point2:
+    def center(points: list[Point2]) -> Point2:
         """Returns the central point for points in list
 
         :param points:"""
@@ -318,7 +323,6 @@ class Point2(Pointlike):
 
 
 class Point3(Point2):
-
     @classmethod
     def from_proto(cls, data) -> Point3:
         """
@@ -327,6 +331,7 @@ class Point3(Point2):
         return cls((data.x, data.y, data.z))
 
     @property
+    # pyre-fixme[11]
     def as_Point(self) -> common_pb.Point:
         return common_pb.Point(x=self.x, y=self.y, z=self.z)
 
@@ -342,14 +347,14 @@ class Point3(Point2):
     def to3(self) -> Point3:
         return Point3(self)
 
-    def __add__(self, other: Union[Point2, Point3]) -> Point3:
+    def __add__(self, other: Point2 | Point3) -> Point3:
         if not isinstance(other, Point3) and isinstance(other, Point2):
             return Point3((self.x + other.x, self.y + other.y, self.z))
+        # pyre-ignore[16]
         return Point3((self.x + other.x, self.y + other.y, self.z + other.z))
 
 
 class Size(Point2):
-
     @property
     def width(self) -> float:
         return self[0]
@@ -360,9 +365,8 @@ class Size(Point2):
 
 
 class Rect(tuple):
-
     @classmethod
-    def from_proto(cls, data):
+    def from_proto(cls, data) -> Rect:
         """
         :param data:
         """
@@ -387,12 +391,12 @@ class Rect(tuple):
 
     @property
     def right(self) -> float:
-        """ Returns the x-coordinate of the rectangle of its right side. """
+        """Returns the x-coordinate of the rectangle of its right side."""
         return self.x + self.width
 
     @property
     def top(self) -> float:
-        """ Returns the y-coordinate of the rectangle of its top side. """
+        """Returns the y-coordinate of the rectangle of its top side."""
         return self.y + self.height
 
     @property
@@ -403,5 +407,5 @@ class Rect(tuple):
     def center(self) -> Point2:
         return Point2((self.x + self.width / 2, self.y + self.height / 2))
 
-    def offset(self, p):
+    def offset(self, p) -> Rect:
         return self.__class__((self[0] + p[0], self[1] + p[1], self[2], self[3]))
