@@ -1,35 +1,38 @@
+from __future__ import annotations
+
 import asyncio
 import sys
 from contextlib import suppress
 
-from aiohttp import ClientWebSocketResponse
+from aiohttp.client_ws import ClientWebSocketResponse
 from loguru import logger
+
+# pyre-fixme[21]
 from s2clientprotocol import sc2api_pb2 as sc_pb
 
 from sc2.data import Status
 
 
 class ProtocolError(Exception):
-
     @property
     def is_game_over_error(self) -> bool:
         return self.args[0] in ["['Game has already ended']", "['Not supported if game has already ended']"]
 
 
-class ConnectionAlreadyClosed(ProtocolError):
+class ConnectionAlreadyClosedError(ProtocolError):
     pass
 
 
 class Protocol:
-
-    def __init__(self, ws):
+    def __init__(self, ws: ClientWebSocketResponse) -> None:
         """
         A class for communicating with an SCII application.
         :param ws: the websocket (type: aiohttp.ClientWebSocketResponse) used to communicate with a specific SCII app
         """
         assert ws
         self._ws: ClientWebSocketResponse = ws
-        self._status: Status = None
+        # pyre-fixme[11]
+        self._status: Status | None = None
 
     async def __request(self, request):
         logger.debug(f"Sending request: {request !r}")
@@ -37,7 +40,7 @@ class Protocol:
             await self._ws.send_bytes(request.SerializeToString())
         except TypeError as exc:
             logger.exception("Cannot send: Connection already closed.")
-            raise ConnectionAlreadyClosed("Connection already closed.") from exc
+            raise ConnectionAlreadyClosedError("Connection already closed.") from exc
         logger.debug("Request sent")
 
         response = sc_pb.Response()
@@ -46,9 +49,9 @@ class Protocol:
         except TypeError as exc:
             if self._status == Status.ended:
                 logger.info("Cannot receive: Game has already ended.")
-                raise ConnectionAlreadyClosed("Game has already ended") from exc
+                raise ConnectionAlreadyClosedError("Game has already ended") from exc
             logger.error("Cannot receive: Connection already closed.")
-            raise ConnectionAlreadyClosed("Connection already closed.") from exc
+            raise ConnectionAlreadyClosedError("Connection already closed.") from exc
         except asyncio.CancelledError:
             # If request is sent, the response must be received before reraising cancel
             try:
@@ -82,6 +85,6 @@ class Protocol:
         result = await self._execute(ping=sc_pb.RequestPing())
         return result
 
-    async def quit(self):
-        with suppress(ConnectionAlreadyClosed, ConnectionResetError):
+    async def quit(self) -> None:
+        with suppress(ConnectionAlreadyClosedError, ConnectionResetError):
             await self._execute(quit=sc_pb.RequestQuit())
