@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Tuple, Union
+from typing import TYPE_CHECKING
 
 from sc2.constants import COMBINEABLE_ABILITIES
 from sc2.ids.ability_id import AbilityId
@@ -11,8 +11,9 @@ if TYPE_CHECKING:
 
 
 class UnitCommand:
-
-    def __init__(self, ability: AbilityId, unit: Unit, target: Union[Unit, Point2] = None, queue: bool = False):
+    def __init__(
+        self, ability: AbilityId, unit: Unit, target: Unit | Point2 | None = None, queue: bool = False
+    ) -> None:
         """
         :param ability:
         :param unit:
@@ -35,8 +36,8 @@ class UnitCommand:
         self.queue = queue
 
     @property
-    def combining_tuple(self) -> Tuple[AbilityId, Union[Unit, Point2], bool, bool]:
+    def combining_tuple(self) -> tuple[AbilityId, Unit | Point2 | None, bool, bool]:
         return self.ability, self.target, self.queue, self.ability in COMBINEABLE_ABILITIES
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return f"UnitCommand({self.ability}, {self.unit}, {self.target}, {self.queue})"
